@@ -1,4 +1,3 @@
-/* $XConsortium: ico.c,v 1.47 94/04/17 20:45:15 gildea Exp $ */
 /***********************************************************
 
 Copyright (c) 1987  X Consortium
@@ -46,7 +45,7 @@ ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS
 SOFTWARE.
 
 ******************************************************************/
-/* $XFree86: xc/programs/ico/ico.c,v 1.10 2003/05/27 22:26:56 tsi Exp $ */
+/* $XFree86: xc/programs/ico/ico.c,v 1.12 2006/01/09 15:00:43 dawes Exp $ */
 
 /******************************************************************************
  * Description
@@ -1141,9 +1140,9 @@ findpoly(const char *name)
 	icoFatal("can't find object %s", name);
 }
 
-int main(argc, argv)
-    int argc;
-    char **argv;
+int main(
+    int argc,
+    char **argv)
 {
 	const char *display = NULL;
 #ifdef MULTIBUFFER
