@@ -19,7 +19,7 @@
   OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
   THE SOFTWARE.
 */
-/* $XFree86: xc/programs/mkfontscale/mkfontscale.c,v 1.22 2003/12/19 02:05:39 dawes Exp $ */
+/* $XFree86: xc/programs/mkfontscale/mkfontscale.c,v 1.25 2005/04/26 00:44:07 dawes Exp $ */
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -47,6 +47,11 @@
 #include "ident.h"
 
 #ifdef NEED_SNPRINTF
+/* In case a non-standard implementation is provided */
+#undef snprintf
+#define snprintf mysnprintf
+#undef vsnprintf
+#define vsnprintf myvsnprintf
 #undef SCOPE
 #define SCOPE static
 #include "snprintf.c"
@@ -67,6 +72,7 @@ char *encodings_array[] =
       "iso8859-7", "iso8859-8", "iso8859-9", "iso8859-10",
       "iso8859-11", "iso8859-12", "iso8859-13", "iso8859-14",
       "iso8859-15", "iso8859-16",
+      "suneu-greek",
       "ansi-1251", "koi8-r", "koi8-u", "koi8-ru", "koi8-e", "koi8-uni",
       "tis620-2",
       "sun.unicode.india-0",
@@ -75,6 +81,7 @@ char *encodings_array[] =
       /* But not "adobe-dingbats", as it uses generic glyph names. */
       "jisx0201.1976-0", "jisx0208.1983-0", "jisx0208.1990-0",
       "jisx0212.1990-0", "big5-0", "big5.eten-0", "big5hkscs-0",
+      "cns11643-1", "cns11643-2", "cns11643-3",
       "gb2312.1980-0", "gb18030.2000-0", "gb18030.2000-1",
       "ksc5601.1987-0", "ksc5601.1992-3"};
 
@@ -400,14 +407,16 @@ static char *widths[] = {
 
 #define NUMWIDTHS (sizeof(widths) / sizeof(widths[0]))
 
+#define NAME_BUFFER_SIZE 500
+
 static char*
 nameWidth(char *name)
 {
-    char buf[500];
+    char buf[NAME_BUFFER_SIZE];
     int i;
     int n = strlen(name);
 
-    if(n >= 499) return NULL;
+    if(n >= NAME_BUFFER_SIZE - 1) return NULL;
     for(i = 0; i < n; i++)
         buf[i] = tolower(name[i]);
     buf[i] = '\0';
@@ -418,37 +427,29 @@ nameWidth(char *name)
     return NULL;
 }
 
-static char*
+static char weightL[NAME_BUFFER_SIZE];
+
+static const char*
 t1Weight(char *weight)
 {
-    if(!weight)
-        return NULL;
-    if(strcmp(weight, "Thin") == 0)
-        return "thin";
-    if(strcmp(weight, "Light") == 0)
-        return "light";
-    if(strcmp(weight, "Regular") == 0)
-        return "medium";
-    if(strcmp(weight, "Normal") == 0)
-        return "medium";
-    if(strcmp(weight, "Medium") == 0)
-        return "medium";
-    if(strcmp(weight, "Book") == 0)
-        return "medium";
-    if(strcmp(weight, "Roman") == 0) /* Some URW++ fonts do that! */
-        return "medium";
-    if(strcmp(weight, "Demi") == 0)
-        return "semibold";
-    if(strcmp(weight, "DemiBold") == 0)
-        return "semibold";
-    else if(strcmp(weight, "Bold") == 0)
-        return "bold";
-    else if(strcmp(weight, "Black") == 0)
-        return "black";
-    else {
-        fprintf(stderr, "Unknown Type 1 weight \"%s\"\n", weight);
-        return NULL;
+    unsigned int i = 0;
+    unsigned int n = strlen(weight);
+    unsigned int j; 
+    unsigned char ch;
+    unsigned char space = ' '; 
+
+    if(n >= NAME_BUFFER_SIZE - 1) return NULL;
+    for(j = 0; j < n; j++) {
+        ch = (unsigned char) tolower(weight[j]);
+    	if ( ch != space) {
+            weightL[i] = ch ;
+	    i++ ;
+	}    
     }
+    weightL[i] = '\0';
+    if(!weightL)
+        return NULL;
+    else return weightL;
 }
 
 static int
@@ -495,8 +496,9 @@ ListPtr
 makeXLFD(char *filename, FT_Face face, int isBitmap)
 {
     ListPtr xlfd = NULL;
-    char *foundry, *family, *weight, *slant, *sWidth, *adstyle, 
+    char *foundry, *family, *slant, *sWidth, *adstyle, 
         *spacing, *full_name;
+    const char *weight;
     TT_Header *head;
     TT_HoriHeader *hhea;
     TT_OS2 *os2;
