@@ -27,7 +27,7 @@
  * Author: Paulo Csar Pereira de Andrade
  */
 
-/* $XFree86: xc/programs/xedit/lisp/compile.c,v 1.16 2003/10/24 20:38:16 tsi Exp $ */
+/* $XFree86: xc/programs/xedit/lisp/compile.c,v 1.18 2005/03/29 18:17:01 tsi Exp $ */
 
 #define VARIABLE_USED		0x0001
 #define VARIABLE_ARGUMENT	0x0002
@@ -2140,9 +2140,10 @@ ComMacroExpandEval(LispCom *com, LispObj *object)
 }
 
 static LispObj *
-ComMacroExpand(LispCom *com, LispObj *lambda)
+ComMacroExpand(LispCom *com, LispObj *l)
 {
     LispObj *result, **presult = &result;
+    LispObj * volatile lambda = l;
     int jumped, *pjumped = &jumped, backquote, *pbackquote = &backquote;
     LispBlock *block;
 
