@@ -1,9 +1,9 @@
-/* $Xorg: fonts.c,v 1.5 2001/02/09 02:05:42 xorgcvs Exp $ */
+/* $XFree86: xc/programs/xfs/difs/fonts.c,v 3.16 2005/10/14 15:17:33 tsi Exp $ */
 /*
  * font control
  */
 /*
- 
+
 Copyright 1990, 1991, 1998  The Open Group
 
 Permission to use, copy, modify, distribute, and sell this software and its
@@ -46,17 +46,16 @@ in this Software without prior written authorization from The Open Group.
  * ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF
  * THIS SOFTWARE.
  */
-/* $XFree86: xc/programs/xfs/difs/fonts.c,v 3.14 2003/11/08 02:02:07 dawes Exp $ */
-
-#include        "FS.h"
-#include        "FSproto.h"
+/*#define DEBUG*/
+#include        <X11/fonts/FS.h>
+#include        <X11/fonts/FSproto.h>
 #include	<stdio.h>
 #include	<stdlib.h>
 #include	<X11/Xos.h>
 #include	"clientstr.h"
 #include	"fsresource.h"
 #include	"difsfnst.h"
-#include	"fontstruct.h"
+#include	<X11/fonts/fontstruct.h>
 #include	"closestr.h"
 #include	"globals.h"
 #include	"difs.h"
@@ -441,6 +440,9 @@ OpenFont(
 	SendErrToClient(client, FSBadName, (pointer) 0);
 	return FSBadName;
     }
+#ifdef DEBUG
+    fprintf(stderr,"OpenFont: %s\n",name);
+#endif
     /*
     ** Check name cache.  If we find a cached version of this font that
     ** is cachable, immediately satisfy the request with it.  If we find
