@@ -1,4 +1,3 @@
-/* $Xorg: PProcess.c,v 1.6 2001/02/09 02:05:57 xorgcvs Exp $ */
 /*
 
 Copyright 1996, 1998  The Open Group
@@ -26,7 +25,7 @@ other dealings in this Software without prior written authorization from
 The Open Group.
 
 */
-/* $XFree86: xc/programs/xrx/plugin/PProcess.c,v 1.7 2003/12/22 17:48:13 tsi Exp $ */
+/* $XFree86: xc/programs/xrx/plugin/PProcess.c,v 1.9 2006/01/09 15:01:45 dawes Exp $ */
 
 #include "RxPlugin.h"
 #include "XUrls.h"
@@ -336,7 +335,8 @@ ResetWMColormap(PluginInstance* This, Window win)
 /***********************************************************************
  * Event Handler to reparent client window under plugin window 
  ***********************************************************************/
-/* static */ void
+static
+void
 SubstructureRedirectHandler (
     Widget widget, 
     XtPointer client_data, 
